﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Mvc;
using Syncfusion.Presentation;

namespace HelloWorld.Controllers
{
    public class HomeController : Controller
    {
        private readonly IHostingEnvironment _appEnvironment;

        public HomeController(IHostingEnvironment appEnvironment)
        {
            _appEnvironment = appEnvironment;
        }

        public IActionResult Index()
        {
            string basePath = _appEnvironment.WebRootPath;
            IPresentation presentation = Presentation.Open(Path.GetFullPath(basePath + @"\HelloWorld.pptx"));
            ISlide slide = presentation.Slides[0];
            IGroupShape groupShape = slide.GroupShapes[0];
            IShapes shapes = groupShape.Shapes;
            foreach(IShape shape in shapes)
            {
                if(shape.SlideItemType == SlideItemType.Picture)
                {
                    shapes.Remove(shape);
                    break;
                }
            }
            MemoryStream ms = new MemoryStream();

            //Saves the presentation to the memory stream.
            presentation.Save(ms);
            //Set the position of the stream to beginning.
            ms.Position = 0;

            //Initialize the file stream to download the presentation.
            FileStreamResult fileStreamResult = new FileStreamResult(ms, "application/vnd.openxmlformats-officedocument.presentationml.presentation");
            //Set the file name.
            fileStreamResult.FileDownloadName = "Sample.pptx";

            return fileStreamResult;
        }

        public IActionResult About()
        {
            ViewData["Message"] = "Your application description page.";

            return View();
        }

        public IActionResult Contact()
        {
            ViewData["Message"] = "Your contact page.";

            return View();
        }

        public IActionResult Error()
        {
            return View();
        }
    }
}
